@@ -1,12 +1,12 @@
 ;;; org-roam-utils.el --- Utilities for Org-roam -*- lexical-binding: t; -*-
 
-;; Copyright © 2020-2022 Jethro Kuan <jethrokuan95@gmail.com>
+;; Copyright © 2020-2025 Jethro Kuan <jethrokuan95@gmail.com>
 
 ;; Author: Jethro Kuan <jethrokuan95@gmail.com>
 ;; URL: https://github.com/org-roam/org-roam
 ;; Keywords: org-mode, roam, convenience
-;; Version: 2.2.1
-;; Package-Requires: ((emacs "26.1") (dash "2.13") (org "9.4"))
+;; Version: 2.3.0
+;; Package-Requires: ((emacs "26.1") (dash "2.13") (org "9.6"))
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -72,11 +72,10 @@ Like `string-equal', but case-insensitive."
 (defun org-roam-whitespace-content (s)
   "Return the whitespace content at the end of S."
   (with-temp-buffer
-    (let ((c 0))
-      (insert s)
-      (skip-chars-backward " \t\n")
-      (buffer-substring-no-properties
-       (point) (point-max)))))
+    (insert s)
+    (skip-chars-backward " \t\n")
+    (buffer-substring-no-properties
+     (point) (point-max))))
 
 (defun org-roam-strip-comments (s)
   "Strip Org comments from string S."
@@ -85,7 +84,8 @@ Like `string-equal', but case-insensitive."
     (goto-char (point-min))
     (while (not (eobp))
       (if (org-at-comment-p)
-          (delete-region (point-at-bol) (progn (forward-line) (point)))
+          (delete-region (line-beginning-position)
+                         (progn (forward-line) (point)))
         (forward-line)))
     (buffer-string)))
 
@@ -120,7 +120,7 @@ SPEC is a list, as per `dolist'."
 ;;; File utilities
 (defun org-roam-descendant-of-p (a b)
   "Return t if A is descendant of B."
-  (unless (equal (file-truename a) (file-truename b))
+  (unless (and a b (equal (file-truename a) (file-truename b)))
     (string-prefix-p (replace-regexp-in-string "^\\([A-Za-z]\\):" 'downcase (expand-file-name b) t t)
                      (replace-regexp-in-string "^\\([A-Za-z]\\):" 'downcase (expand-file-name a) t t))))
 
@@ -229,36 +229,10 @@ Like `org-fontify-like-in-org-mode', but supports `org-ref'."
     (insert s)
     (let ((org-ref-buffer-hacked t))
       (org-mode)
-      (org-font-lock-ensure)
+      (setq-local org-fold-core-style 'overlays)
+      (font-lock-ensure)
       (buffer-string))))
 
-;;;; Shielding regions
-(defface org-roam-shielded
-  '((t :inherit (warning)))
-  "Face for regions that are shielded (marked as read-only).
-This face is used on the region target by org-roam-insertion
-during an `org-roam-capture'."
-  :group 'org-roam-faces)
-
-(defun org-roam-shield-region (beg end)
-  "Shield region against modifications.
-BEG and END are markers for the beginning and end regions.
-REGION must be a cons-cell containing the marker to the region
-beginning and maximum values."
-  (add-text-properties beg end
-                       '(font-lock-face org-roam-shielded
-                                        read-only t)
-                       (marker-buffer beg)))
-
-(defun org-roam-unshield-region (beg end)
-  "Unshield the shielded REGION.
-BEG and END are markers for the beginning and end regions."
-  (let ((inhibit-read-only t))
-    (remove-text-properties beg end
-                            '(font-lock-face org-roam-shielded
-                                             read-only t)
-                            (marker-buffer beg))))
-
 ;;; Org-mode utilities
 ;;;; Motions
 (defun org-roam-up-heading-or-point-min ()
@@ -364,26 +338,14 @@ If the property is already set, it's value is replaced."
 (defun org-roam-add-property (val prop)
   "Add VAL value to PROP property for the node at point.
 Both, VAL and PROP are strings."
-  (let* ((p (org-entry-get (point) prop))
-         (lst (when p (split-string-and-unquote p)))
-         (lst (if (memq val lst) lst (cons val lst)))
-         (lst (seq-uniq lst)))
-    (org-set-property prop (combine-and-quote-strings lst))
-    val))
+  (org-roam-property-add prop val))
 
 (defun org-roam-remove-property (prop &optional val)
   "Remove VAL value from PROP property for the node at point.
 Both VAL and PROP are strings.
 
 If VAL is not specified, user is prompted to select a value."
-  (let* ((p (org-entry-get (point) prop))
-         (lst (when p (split-string-and-unquote p)))
-         (prop-to-remove (or val (completing-read "Remove: " lst)))
-         (lst (delete prop-to-remove lst)))
-    (if lst
-        (org-set-property prop (combine-and-quote-strings lst))
-      (org-delete-property prop))
-    prop-to-remove))
+  (org-roam-property-remove prop val))
 
 (defun org-roam-property-add (prop val)
   "Add VAL value to PROP property for the node at point.
@@ -487,8 +449,10 @@ See <https://github.com/raxod502/straight.el/issues/520>."
                       (quit "N/A"))))
     (insert (format "- Org: %s\n" (org-version nil 'full)))
     (insert (format "- Org-roam: %s" (org-roam-version)))
-    (insert (format "- sqlite-connector: %s" org-roam-database-connector))))
-
+    (insert (format "- sqlite-connector: %s"
+                    (if-let ((conn (org-roam-db--get-connection)))
+                        (eieio-object-class conn)
+                      "not connected")))))
 
 (provide 'org-roam-utils)
 ;;; org-roam-utils.el ends here
